; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s
;  Note that if you modify the button remapping scheme here, this character will
; still be able to correctly detect the basic commands of other characters
; complying with the basic command order specified below, as long as their
; buttons haven't been remapped.  But no character (not even one with the same
; remapping scheme, not even another instance of this character) will be able to
; correctly detect this character's commands.  This shouldn't ever result in any
; false positives, but it could delay correct positives, and could erroneously
; make the helper AI activation method trigger a false negative in team simul
; modes, in which case the XOR-ed commands method would be needed to provide
; backup.  But of course, this isn't an issue in any version of Mugen prior to
; version 2002.04.14.

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


; These 11 Single Button and Hold Dir commands must be placed here at the top
; of the CMD, above all other commands, and in the standard order shown here,
; in order for the "Compatibly Partnered" version (9742) of the helper AI
; activation method to work with different partners in simul team mode.
; (When the partner is not compatible, then it's best to just use the regular
; version (9741) and rely on the XOR method for backup in case a human
; partner's input turns off the CPU partner's AI.)
;   (Now, even if you do not intend to give your character any custom AI, it
; would still be nice if you would place the commands at the top of your CMD,
; for the sake of other characters which do use this AI activation method.
; And then, define Anim 9741 in your AIR file to indicate to other characters
; that your character is compatible.
;   It may slightly increase the chances of faulty AI activation if the user
; is using characters with a poor implementation of the old humanly-impossible
; commands AI activation method when fighting against your character, but
; other than that, there's really no particular reason not to.  And you can
; change the names of the commands if you want.  For compatibility, all that
; really matters is the "command" and "time" parameters.)
;
; Please don't add any extra definitions for any of these 11 basic command
; names, nor for any of the 7 "hold[button]" command names that follow.
; For example, things like this should be avoided:
;	[Command]
;	name = "z"
;	command = y+b
;	time = 1
; There are several workarounds possible to achieve the same effect.  Please
; feel free to ask me about it if you have any uncertainty.
; Violating this rule would cause the KeyCtrl Helper method and/or the XORed
; Commands method to malfunction, and could also interfere with other future
; applications of this command order standard.
;
;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

; Here add matching commands for any moves that must never be used randomly
; by the computer, such as suicide moves and super moves, and add the pairs
; to the XOR VarSet controller in State -3.

; If you're desperate to make sure that the AI always gets turned on as soon
; as possible, you can add more equivalents for your own commands here too,
; and add to the XOR VarSet controller's triggers accordingly.

; And of course, if you've run out of unique command labels (Mugen allows
; 128), you can remove as many of these as you want.  You'll of course need
; to modify the XOR VarSet controller's triggers accordingly, but Mugen
; will let you know if you forget to do so. :)


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "QCF_2p"
command = ~D, DF, F, x+y

[Command]
name = "DP_2p"
command = ~F, D, DF, x+y

[Command]
name = "QCF_2k"
command = ~D, DF, F, a+b

[Command]
name = "DP_2k"
command = ~F, D, DF, a+b

[Command]
name = "QCB_2p"
command = ~D, DB, B, x+y

[Command]
name = "QCB_2k"
command = ~D, DB, B, a+b

[Command]
name = "DD_2k"
command = ~D,D, a+b

[Command]
name = "HCF_2p"
command = ~B, DB, D, DF, F, x+y
[Command]
name = "HCF_2p"
command = ~B, D, F, x+y

;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "HCB_a"
command = ~F, DF, D, DB, B, a
[Command]
name = "HCB_b"
command = ~F, DF, D, DB, B, b
[Command]
name = "HCB_a"
command = ~F, D, B, a
[Command]
name = "HCB_b"
command = ~F, D, B, b
[Command]
name = "HCB_2k"
command = ~F, DF, D, DB, B, a+b
[Command]
name = "HCB_2k"
command = ~F, D, B, a+b

[Command]
name = "DP_a"
command = ~F, D, DF, a

[Command]
name = "DP_b"
command = ~F, D, DF, b

[Command]
name = "DD_a"
command = ~D,D, a
[Command]
name = "DD_b"
command = ~D,D, b

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCB_pari"
command = ~D, DB, B, c

[Command]
name = "QCF_pari"
command = ~D, DF, F, c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "AFF"     ;Required (do not remove)
command = $F, ~F, F
time = 10

[Command]
name = "ABB"     ;Required (do not remove)
command = $B, ~B, B
time = 10

[Command]
name = "DAUN"     ;Required (do not remove)
command = ~$D
buffer.time = 5


[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "dbug"
command = c+z
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; DEBUG
;[State -1, DEBUG]
;type = ChangeState
;value = 696969
;triggerall = !numhelper(3101)
;triggerall = !var(55)
;triggerall = roundno <= 1
;trigger1 = command = "start"
;trigger1 = command = "x"
;trigger1 = roundstate = 2

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

; This is generally the best place to put most of your AI directives.  For
; example, this controller would only be executed when the CPU is in control:
;
; [State -1, Haha!]
; type = ChangeState
; trigger1 = var(0) ; (Or use "var(58)>0" if you've chosen not to
;                   ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType = S
; trigger1 = MoveType = I
; trigger1 = P2MoveType = H
; trigger1 = NumEnemy = 1
; trigger1 = Enemy,GetHitVar(HitTime) > 60
; trigger1 = PrevStateNo != 195
; trigger1 = Random < 99
; value = 195

; And of course, most human-only command-based ChangeStates also belong
; in State -1.  For example, this move would only be performable by a human:
;
; [State -1, Death Before Dishonor]
; type = ChangeState
; trigger1 = command = "suicide"
; trigger1 = !var(0) ; (Or use "var(58)<1" if you've chosen not to
;                    ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType != A
; trigger1 = MoveType = I
; value = {suicide state number}


;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
;[State -1, Triple Kung Fu Palm]
;type = ChangeState
;value = 3000
;triggerall = command = "TripleKFPalm"
;triggerall = power >= 1000
;trigger1 = statetype = S
;trigger1 = ctrl
;trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA, HA
;trigger2 = stateno != [3000,3050)
;trigger2 = movecontact

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(9) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [300,359]) || (stateno = [500,599])
;trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = anim != 232 && anim != 211 && anim != 214 && anim != 218 && anim != 240 && anim != 414 && anim != 444 && anim != 242 && anim != 433 && anim != 221
trigger2 = (stateno != [342,349])
trigger2 = movecontact || movereversed
trigger3 = stateno = 390 || stateno = 392 || stateno = 391 || stateno = 393
trigger3 = movecontact
var(9) = 1

[State -1, Last Arc]
type = ChangeState
value = 3800
trigger1 = power >= 3000
trigger1 = movecontact > 1
trigger1 = stateno = 394
trigger1 = var(0) = 1

; AI


[State -1, AI Tactic Cycle]
type = VarSet
triggerall = var(55)
trigger1 = stateno != [120,169]
trigger1 = movetype = H
trigger1 = time = 1
trigger2 = p2stateno = 5110
trigger2 = random < 500
trigger3 = p2stateno = 1001
var(54) = random%2

[State -1, AI(R) Throw]
type = ChangeState
value = 870
triggerall = var(55)
triggerall = statetype = A
triggerall = ctrl
trigger1 = p2bodydist X < 14
trigger1 = abs(p2bodydist y) < 40
trigger1 = (p2statetype = A)
trigger1 = p2movetype != H

[State AI, Reach]
type = ChangeState
triggerall = !numhelper(3101)
triggerall = var(55)
triggerall = p2bodydist x >= 150
triggerall = statetype != A
triggerall = var(54) != 2
triggerall = stateno != 40
triggerall = command = "SupahJump"
triggerall = command = "holdfwd"
trigger1 = ctrl
value = 40

[State AI, Kung Fu Throw]
type = ChangeState
value = ifelse((random<100||var(8) > 0)&&power>=1000&&var(28)>0,1690,ifelse(random<100,40,ifelse(random<333&&var(28)>=0,1650,ifelse(random<500,830,800))))
triggerall = var(55)
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = stateno != 40
triggerall = random < 900 || var(54) = 2
triggerall = p2stateno != [5100,5200]
triggerall = prevstateno != [800,899]
triggerall = var(8) <= 0 || (power >= 1000 && var(28)>0)
trigger1 = p2bodydist X <= 5
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

[State AI, Guard S]
type = ChangeState
triggerall = stateno != 40
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = stateno != 390
triggerall = var(54) = 2
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<64&&(stateno!=[120,169])&&p2bodydist x<=80,ifelse(random<150,ifelse(random<150&&var(28)>0&&p2statetype!=A,1600,396),390),130)

[State AI, Guard L]
type = ChangeState
triggerall = stateno != 40
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = stateno != 392
triggerall = var(54) = 2
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<50&&(stateno!=[120,169])&&p2bodydist x<=80,ifelse(random<150&&power>=1000&&var(28)>0,1640,ifelse(random<100,40,392)),131)

[State AI, Parry A]
type = ChangeState
triggerall = !numhelper(3101)
;triggerall = power
;triggerall = var(54) != 1
triggerall = random < 100
triggerall = stateno != [120,169]
triggerall = prevstateno != [120,169]
triggerall = stateno != 394
triggerall = var(54) = 2
triggerall = (var(55)) && (StateType = A) && (Ctrl) && (EnemyNear, Facing != Facing)
trigger1 = (var(54)!=2) && (P2MoveType = A) && ((inguarddist) || (EnemyNear, NumProj > 0)) && (enemynear,moveguarded < 12) && (!var(51))
trigger2 = (var(54)=2) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = 394

; AI CONSIDERATIONS

[State -1, AI Consideration reset]
type = VarSet
trigger1 = 1
var(52) = 0

[State AI, COUNTER]
type = VarSet
trigger1 = (var(55))
trigger1 = var(0) = 1
trigger1 = movecontact = 5
trigger1 = random < 110
trigger1 = power < 3000 || statetype != A
trigger1 = p2movetype = A
var(52) = ifelse(statetype=A,610,ifelse(statetype=C,410,210))
[State AI, Carry on parrying]
type = VarSet
trigger1 = (var(55))
trigger1 = var(0) = 0
trigger1 = movecontact = 5
trigger1 = random < 500
trigger1 = power < 3000 || statetype != A
trigger1 = p2movetype = A
var(52) = ifelse( random < 110 , ifelse(statetype=A,395,391) , ifelse(statetype=A,394,ifelse(statetype=C,392,390)) )

[State AI, Consider backing off]
type = VarSet
triggerall = var(55)
triggerall = random < 200
triggerall = numenemy
triggerall = (p2stateno = [5080,5130]) || ((enemynear,time <= 10) && (enemynear,prevstateno = 5120))
triggerall = p2bodydist x <= 40
triggerall = backedgedist >= 40
trigger1 = stateno != 40
trigger1 = ctrl
var(52) = ifelse(random<750,105,40)

[State AI, Consider S.LP]
type = VarSet
triggerall = var(52) = 0 || random < 326
triggerall = var(55)
triggerall = random < 170 + (20*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,25-(5*(movehit>=1))]
triggerall = p2bodydist y >= -110
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = ctrl
trigger2 = (stateno = 200) && (anim != 201 && anim != 202)
trigger2 = movecontact
trigger3 = ((stateno = 430) && (anim = 432)) || ((stateno = 230) && (anim = 233)) || ((stateno = 240) && (anim = 246) && movecontact) || ((stateno = 400) && (anim = 403)) || ((stateno = 430) && (anim = 432))
trigger3 = movecontact
trigger4 = (stateno = 1120 && anim = 1121) || (stateno = 1150 && anim = 1157)
trigger4 = movehit && (p2statetype != A)
var(52) = 200

[State AI, Consider S.LK]
type = VarSet
triggerall = var(52) = 0 || random < 326
triggerall = var(55)
triggerall = random < 165 + (20*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (stateno = [1600,1630])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,40-(5*(movehit>=1))]
triggerall = p2bodydist y >= -90
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 150
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 230 && anim != 232)
trigger2 = movecontact
trigger2 = anim != [231,239]
trigger3 = (stateno = 210 && anim = 216) || ((stateno = 240) && (anim = 246) && movecontact)
trigger3 = movecontact
trigger4 = (stateno = 1120 && anim = 1121) || (stateno = 1150 && anim = 1157)
trigger4 = movehit && (p2statetype != A)
trigger5 = (stateno = 300) || (stateno = 330)
trigger5 = movecontact
var(52) = 230

[State AI, Consider S.HK]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 115 + (40*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,90]
triggerall = p2bodydist y >= -60
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 120
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 230 && anim != 232) || (stateno = 210 && anim = 216) || (stateno = 250 && anim = 250) || (stateno = 210 && anim = 213)
trigger2 = movecontact
trigger3 = (stateno = 1100 && anim = 1101 && animelemtime(12) >= 0)
trigger3 = (movehit) && (p2statetype != A)
trigger4 = (stateno = 300) || (stateno = 330) || (stateno = 310) || (stateno = 500) || (stateno = 530) || (stateno = 510) || (stateno = 350)
trigger4 = prevstateno != 340
trigger4 = movecontact
var(52) = 240

[State AI, Consider S.HP]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 110 + (50*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,97]
triggerall = p2bodydist y >= -70
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 230 && anim != 232)
trigger2 = movecontact
trigger3 = (stateno = 210 && anim = 216) || ((stateno = 430) && (anim = 432))
trigger3 = movecontact
trigger4 = (stateno = 1100 && anim = 1101 && animelemtime(12) >= 0)
trigger4 = (movehit) && (p2statetype != A)
trigger5 = (stateno = 300) || (stateno = 330) || (stateno = 500) || (stateno = 530)
trigger5 = movecontact
var(52) = 210

[State AI, Consider S.FP]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 100
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,130]
triggerall = p2bodydist y >= -120
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = ctrl
trigger2 = (stateno = [200,249]) || (stateno = [400,440])
trigger2 = stateno != 220
trigger2 = stateno != 250
trigger2 = anim != 233 && anim != 211 && anim != 214 && anim != 218 && anim != 240 && anim != 414 && anim != 444 && anim != 242
trigger2 = movecontact
trigger3 = (stateno = 1120 && anim = 1121)
trigger3 = movehit
trigger4 = (stateno = 310) || (stateno = 500) || (stateno = 530) || (stateno = 510) || (stateno = 340) || (stateno = 540)
trigger4 = movecontact
trigger4 = prevstateno != 350
trigger4 = movecontact
var(52) = 220


[State AI, Consider S.FK]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 45 + (40*p2statetype=C)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,77]
triggerall = p2bodydist y >= -110
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = ctrl
trigger2 = (stateno = [200,249]) || (stateno = [400,440])
trigger2 = stateno != 220
trigger2 = stateno != 250
trigger2 = anim != 233 && anim != 211 && anim != 214 && anim != 218 && anim != 240 && anim != 414 && anim != 444 && anim != 242 && anim != 243
trigger2 = movecontact
trigger3 = (stateno = 1120 && anim = 1121)
trigger3 = movehit
trigger4 = (stateno = 300) || (stateno = 330) || (stateno = 310) || (stateno = 500) || (stateno = 530) || (stateno = 510) || (stateno = 340) || (stateno = 540)
trigger4 = prevstateno != 350
trigger4 = moveguarded
trigger4 = p2statetype = C
var(52) = 250


[State AI, Consider C.LP]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 160 + (20*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (stateno = [1600,1630])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,43-(5*(movehit>=1))]
triggerall = p2bodydist y >= -30
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -20
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = ctrl
trigger2 = ((stateno = 400) && (anim != 402)) || ((stateno = 430) && (anim = 434))
trigger2 = (time > 9) || (movecontact && (time >= 6 || anim != 401) )
trigger3 = (stateno = 500) || (stateno = 530)
trigger3 = (time > 9) || movecontact
var(52) = 400

[State AI, Consider C.LK]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 155 + (20*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (stateno = [1600,1630]) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,44-(5*(movehit>=1))]
triggerall = p2bodydist y >= -20
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430 && anim != 431 && anim != 433 && anim != 434)
trigger2 = (time > 9) || (movecontact && time > 5)
trigger3 = (stateno = 500) || (stateno = 530)
trigger3 = (time > 9) || movecontact
var(52) = 430

[State AI, Consider C.HP]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 150 + (50*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,53-(5*(movehit>=1))]
triggerall = p2bodydist y >= -80
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -50
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430 && anim != 433)
trigger2 = movecontact
trigger3 = (stateno = 440 && anim = 442)
trigger3 = movecontact
trigger4 = (stateno = 500) || (stateno = 530) || (stateno = 300) || (stateno = 330) || (stateno = 310)
trigger4 = movecontact
var(52) = 410


[State AI, Consider C.HK]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 120 + (40*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,93]
triggerall = p2bodydist y >= -20
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 150
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430 && anim != 433)
trigger2 = movecontact
trigger3 = (stateno = 500) || (stateno = 530) || (stateno = 510) || (stateno = 300) || (stateno = 330) || (stateno = 310)
trigger3 = movecontact
var(52) = 440


[State AI, Consider QCB+Y]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 100
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno = 5120
triggerall = p2bodydist x = [9,31]
triggerall = p2statetype != A
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = ctrl
var(52) = 1670

[State AI, Consider DP+B]
type = VarSet
triggerall = var(52) = 0 || random < 300
triggerall = var(55)
triggerall = random < 175 + (200*(p2movetype = H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (random < 350)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,37-(p2dist y/1.5)-(6*(movehit>=1))]
triggerall = p2bodydist y >= -200
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -12
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 200
trigger1 = var(9) && ((stateno != 200 && stateno != 230 && stateno != 400 && stateno != 430) || random < 100)
var(52) = 1570

[State AI, Consider DP+A]
type = VarSet
triggerall = var(52) = 0 || random < 300
triggerall = var(55)
triggerall = random < 180 + (200*(p2movetype = H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (random < 350)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,27-(p2dist y/1.5)-(6*(movehit>=1))]
triggerall = p2bodydist y >= -180
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -12
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 200
trigger1 = var(9) && ((stateno != 200 && stateno != 230 && stateno != 400 && stateno != 430) || random < 100)
var(52) = 1550

[State AI, Consider DP+X]
type = VarSet
triggerall = var(52) = 0 || random < 300
triggerall = var(55)
triggerall = random < 185
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = ifelse(stateno!=1530,(p2bodydist x = [55,75]),(p2bodydist x = [-5,85]))
triggerall = p2bodydist y >= -120
triggerall = p2bodydist y <= -50 || random < 80 || (stateno = 1530)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 300
trigger1 = var(9)
trigger2 = stateno = 1530
trigger2 = movehit
var(52) = 1750

[State AI, Consider DP+Y]
type = VarSet
triggerall = var(52) = 0 || random < 300
triggerall = var(55)
triggerall = random < 190
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = ifelse(stateno!=1530,(p2bodydist x = [65,86]),(p2bodydist x = [-5,100]))
triggerall = p2bodydist y >= -120
triggerall = p2bodydist y <= -50 || random < 80 || (stateno = 1530)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 350
trigger1 = var(9)
trigger2 = stateno = 1530
trigger2 = movehit
var(52) = 1770


[State AI, Consider stomping]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 145
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (random < 200)
triggerall = p2stateno != 5120
triggerall = p2bodydist x = [15,56-(10*(movehit>=1))]
triggerall = p2bodydist y >= -60
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = var(9) && ((stateno != 200 && stateno != 230 && stateno != 400 && stateno != 430) || random < 100 || moveguarded)
var(52) = ifelse(random<100&&power>=1000,1640,ifelse(random<500||(stateno=[200,599]),1600,1620))

[State AI, Consider QCF+B]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 100
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (random < 250)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,70]
triggerall = p2bodydist y >= -110
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -20
triggerall = statetype != A
triggerall = p2statetype != C
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = var(9) && (stateno != 200 && stateno != 230 && stateno != 400 && stateno != 430)
trigger2 = stateno = 1510
trigger2 = movecontact
var(52) = 1530

[State AI, Consider Shield Bunking]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 256
triggerall = var(55)
triggerall = random < 80 + (40*p2movetype=A)
triggerall = !var(51)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [35,70]
triggerall = p2bodydist y >= -60
triggerall = p2movetype != H
triggerall = statetype != A
triggerall = (p2movetype != A || (enemynear,time>=4) || random < 100)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 600
trigger1 = stateno != [390,396]
trigger1 = ctrl
var(52) = 396

[State AI, Consider QCF+X]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 125
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (random < 250)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,74]
triggerall = p2bodydist y >= -70
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -35
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = var(9) && (stateno != 200 && stateno != 230 && stateno != 400 && stateno != 430)
var(52) = 1500


[State AI, Consider QCF+A]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 130
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (random < 250)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,78]
triggerall = p2bodydist y >= -50
triggerall = statetype != A
triggerall = p2statetype != C || random < 100
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = var(9) && (stateno != 200 && stateno != 230 && stateno != 400 && stateno != 430)
var(52) = 1510

[State AI, Consider QCF+Y]
type = VarSet
triggerall = var(52) = 0 || random < 111
triggerall = var(55)
triggerall = random < 105
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394]) || (random < 250)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,96]
triggerall = p2bodydist y >= -70
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -35
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = var(9) && (stateno != 200 && stateno != 230 && stateno != 400 && stateno != 430)
var(52) = 1520

[State AI, Consider Spamming a basic move]
type = VarSet
triggerall = var(52) = 0 || random < 326
triggerall = var(55)
triggerall = random < 200 - (p2dist x/2) + (20*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,110]
triggerall = p2bodydist y >= -90
triggerall = statetype != A
triggerall = var(28) <= 0
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 150
trigger1 = ctrl
trigger2 = stateno = [200,459]
trigger2 = movecontact
var(52) = ifelse(p2bodydist x<=60,ifelse(random<500||p2statetype=C,400,200) + (10*random%6),ifelse(random<250,250,ifelse(random<500,440,230)))

[State AI, Consider Spamming a special move]
type = VarSet
triggerall = var(52) = 0 || random < 126
triggerall = var(55)
triggerall = random < 100 - (p2dist x/4) + (20*(p2movetype=H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [25,140]
triggerall = p2bodydist y >= -90
triggerall = statetype != A
triggerall = var(28) <= 0
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100
trigger1 = var(9)
var(52) = 1500 + (50*random%6)  + (10*random%4)


[State AI, Consider a straight super]
type = VarSet
triggerall = var(55)
triggerall = random < 60 + (200*(p2movetype = H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || random < 100
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [25,100]
triggerall = p2bodydist y >= -60
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = ( enemynear, vel y <= 0 ) || ( enemynear, vel y + pos y <= -16 ) || ( p2statetype != A )
triggerall = var(28) > 0 || p2statetype != A
triggerall = statetype != A
triggerall = power >= 1000
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger1 =(p2movetype = H) || (enemynear, ctrl = 0)
trigger1 = p2stateno != [120,165]
var(52) = 1540

[State AI, Consider an anti-air super]
type = VarSet
triggerall = var(55)
triggerall = random < 60 + (200*(p2movetype = H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || random < 200
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5-(p2dist y/1.5),35-(p2dist y/1.5)-(6*(movehit>=1))]
triggerall = p2bodydist y = [-200,30]
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -35
triggerall = ( enemynear, vel y <= 0 ) || ( enemynear, vel y + pos y <= -16 ) || ( p2statetype != A )
triggerall = power >= 1000
triggerall = !numhelper(1599)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 400
trigger1 =(p2movetype = H) || (enemynear, ctrl = 0)
trigger1 = p2stateno != [120,165]
var(52) = ifelse(statetype=A,1592,1590)

[State AI, Consider a manly super]
type = VarSet
triggerall = var(52) = 0 || random < 326
triggerall = var(55)
triggerall = random < 100 + (200*(p2movetype = H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (stateno = [390,394])  || random < 200
triggerall = p2stateno != [5080,5130]
triggerall = ifelse(stateno!=1530,(p2bodydist x = [44,55]),(p2bodydist x = [-5,75]))
triggerall = p2bodydist y = [-120,-60]
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 400
trigger1 = var(9)
trigger2 = stateno = 1530
trigger2 = movehit
var(52) = 1790

[State AI, Consider a uber-manly super]
type = VarSet
triggerall = var(55)
triggerall = random < 105 + (240*(p2movetype = H))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || random < 250
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-25,170]
triggerall = p2bodydist y >= -70
triggerall = statetype != A
triggerall = power >= 2000
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500
trigger1 =(p2movetype = H) || (enemynear, ctrl = 0) || (var(28) <= 0)
trigger1 = (p2stateno != [120,165]) || (p2bodydist x <= 15)
var(52) = 3500

[State AI, Consider Advancing]
type = VarSet
triggerall = var(55)
triggerall = random < 200
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing)) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x >= 85
triggerall = statetype != A
trigger1 = stateno != 40
trigger1 = !moveguarded
var(52) = ifelse(random<850&&p2movetype!=A||command="holdfwd",100,ifelse(random<80,1642,ifelse(random<500,1630,1610)))


; jumpy

[State AI, Consider J.LP]
type = VarSet
triggerall = var(55)
triggerall = random < 100
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,22+vel x]
triggerall = p2bodydist y = [-91,60]
triggerall = vel y > 0 || random < 50 || p2statetype = A || p2movetype = A
trigger1 = statetype = A
var(52) = ifelse(random<500,630,600)

[State AI, Consider J.HP]
type = VarSet
triggerall = var(55)
triggerall = random < 200
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,46+vel x]
triggerall = p2bodydist y = [-91,50]
triggerall = vel y > 0 || random < 50 || p2statetype = A || p2movetype = A
trigger1 = statetype = A
var(52) = 610

[State AI, Consider J.HK]
type = VarSet
triggerall = var(55)
triggerall = random < 250
triggerall = p2stateno != [5080,5130]
triggerall = (p2bodydist x + vel x) = [-9,44]
triggerall = p2bodydist y = [-91+vel y,80+vel y]
triggerall = vel y > 0 || random < 300 || p2statetype = A || p2movetype = A
triggerall = pos y <= -24 || vel y < 0
trigger1 = statetype = A
var(52) = 640

[State AI, Consider spam]
type = VarSet
triggerall = var(55)
triggerall = random < 200
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,35+vel x]
triggerall = p2bodydist y = [-91,60]
triggerall = vel y > 0 || random < 50 || p2statetype = A || p2movetype = A
triggerall = var(28) <= 0
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = [600,649]
trigger2 = movecontact
var(52) = 600 + (10*random%2) + (30*random%2)

[State AI, Consider Air DP+K]
type = VarSet
triggerall = var(55)
triggerall = random < 250 || movehit
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-9,30+ifelse(movecontact,15,0)]
triggerall = p2bodydist y = [-111,40]
triggerall = pos y <= -20 || random < 50
trigger1 = statetype = A
trigger2 = stateno = [700,749]
trigger2 = anim != 741 || random < 100
trigger2 = movecontact
var(52) = ifelse(random<500,1560,1580)

[State AI, Consider Falcon Kick]
type = VarSet
triggerall = var(55)
triggerall = random < 200
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [15,90-(enemynear,vel x)]
triggerall = p2bodydist y = [(p2bodydist x / 1.5)-18,(p2bodydist x / 1.5)+18]
triggerall = numenemy
triggerall = abs(enemynear,vel x) <= 4.5 || random < 250
triggerall = vel y > 0 || random < 50 || p2movetype = A
triggerall = pos y <= -26
trigger1 = statetype = A
trigger2 = stateno = [600,749]
trigger2 = movecontact
var(52) = ifelse(random<500,1720,1700)

[State AI, Consider wasting a powerbar]
type = VarSet
triggerall = var(55)
triggerall = var(28) > 0
triggerall = random < 100
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-9,35]
triggerall = p2bodydist y = [-57,10]
triggerall = power >= 1000
triggerall = prevstateno != 1740
triggerall = p2life <= 200
trigger1 = stateno = 1721
trigger2 = (stateno = [700,749]) || (stateno = 1720)
trigger2 = movehit
trigger3 = stateno = 1550 || stateno = 1570
trigger3 = animelemtime(9) >= 0
trigger3 = movehit
trigger4 = stateno = 1560 || stateno = 1580
trigger4 = animelemtime(6) >= 0
trigger4 = movehit
var(52) = 1740

; Specific Combo

[State AI, Rekka followup 1]
type = VarSet
triggerall = var(52) = 0 || random < 500
triggerall = var(55)
triggerall = random < 500 || movehit
triggerall = p2bodydist y >= -70
triggerall = statetype != A
trigger1 = stateno = 1500 || stateno = 1520
trigger1 = movecontact
var(52) = ifelse(random<500&&p2bodydist x>=120,1502,1501)

[State AI, Rekka followup gut]
type = VarSet
triggerall = var(52) = 0 || random < 500
triggerall = var(55)
triggerall = random < 450 || (moveguarded && p2statetype = S)
triggerall = p2bodydist x = [-5,72]
triggerall = p2bodydist y >= -100
triggerall = statetype != A
triggerall = p2statetype != C
trigger1 = stateno = 1500 || stateno = 1520
trigger1 = movecontact
var(52) = 1505

[State AI, Rekka followup kick]
type = VarSet
triggerall = var(52) = 0 || random < 500
triggerall = var(55)
triggerall = random < 400
triggerall = p2bodydist x = [-5,150]
triggerall = p2bodydist y >= -100
triggerall = statetype != A
triggerall = p2statetype != S
trigger1 = stateno = 1501 || stateno = 1521
trigger1 = movecontact
var(52) = ifelse(random<500||movehit||(p2bodydist x>=60&&!moveguarded),1522,1502)

[State AI, Rising kick followup]
type = VarSet
triggerall = var(52) = 0 || random < 500
triggerall = var(55)
triggerall = p2bodydist x = [-35,50]
triggerall = p2bodydist y = [-57,25]
triggerall = movehit
trigger1 = stateno = 1550 || stateno = 1570
trigger1 = animelemtime(9) >= 0
trigger2 = stateno = 1560 || stateno = 1580
trigger2 = animelemtime(6) >= 0
var(52) = 1551

[State AI, Something]
type = VarSet
triggerall = var(55)
triggerall = stateno = 1651
trigger1 = animelem = 12
trigger1 = random < 80
trigger1 = power >= 1000
var(52) = 1662

[State AI, Something]
type = VarSet
triggerall = var(55)
triggerall = stateno = 1651
trigger1 = animelem = 14
trigger1 = random < 850
trigger1 = random < 80 || frontedgedist < 60 || backedgedist < 60
var(52) = ifelse(random<500,1654,1657)

[State AI, Jump-in]
type = VarSet
triggerall = var(52) != 0 || random < 500
triggerall = var(55)
triggerall = random < 500
triggerall = statetype != A
triggerall = command != "holdback"
trigger1 = stateno = 320 || stateno = 1750 || stateno = 1770 || stateno = 1790 || stateno = 510
trigger1 = movehit
trigger1 = p2statetype = A
var(52) = 40

[State AI, Jump-in]
type = VarSet
triggerall = var(52) != 0 || random < 500
triggerall = var(55)
triggerall = command != "holdback"
trigger1 = stateno = 740
trigger1 = anim = 741
trigger1 = movehit
trigger1 = p2statetype = A
var(52) = 45

;

; AIEND

;---------------------------------------------------------------------------
;Supers
[State -1, GALACTICA]
type = ChangeState
value = 3500
triggerall = (command = "HCF_2p") || (var(52) = 3500)
triggerall = power >= 2000
triggerall = !numhelper(3101)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = anim = 233 || anim = 211 || anim = 214 || anim = 218 || anim = 240 || anim = 414 || anim = 444 || anim = 242
trigger2 = movecontact
trigger3 = stateno = [1000,1250]
trigger3 = movecontact
trigger3 = statetype != A
trigger4 = stateno = 3041 || stateno = 3032 || (stateno = 3030 && hitcount >= 2)
trigger4 = time >= 6
trigger5 = stateno = 1500 || stateno = 1520  || stateno = 1510  || stateno = 1530 || (stateno = 1505 && animelemtime(5)>= 0)
trigger5 = time >= 15

[State -1, MANLINESS]
type = ChangeState
value = 1790
triggerall = (command = "HCB_2k" && (!var(55) || p2statetype = A || p2bodydist x <= 65)) || (var(52) = 1790)
triggerall = power >= 1000
triggerall = !numhelper(3101)
triggerall = var(28) > 0
trigger1 = var(9) ;Use combo condition (above)
trigger2 = anim = 233 || anim = 211 || anim = 214 || anim = 218 || anim = 240 || anim = 414 || anim = 444 || anim = 242
trigger2 = movecontact
trigger3 = stateno = [1000,1250]
trigger3 = movecontact
trigger3 = statetype != A
trigger4 = stateno = 3041 || stateno = 3032 || (stateno = 3030 && hitcount >= 2)
trigger4 = time >= 6
trigger5 = stateno = 1500 || stateno = 1520  || stateno = 1510  || stateno = 1530 || (stateno = 1505 && animelemtime(5)>= 0)
trigger5 = time >= 15


[State -1, QCF+2P]
type = ChangeState
value = ifelse( var(28) <= 0 , 3000 + (random%8 * 10) , 1540)
triggerall =(command = "QCF_2p" && (!var(55) || p2movetype = H)) || (var(52) = 1540)
triggerall = power >= 1000
triggerall = !numhelper(3101)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = anim = 233 || anim = 211 || anim = 214 || anim = 218 || anim = 240 || anim = 414 || anim = 444 || anim = 242
trigger2 = movecontact
trigger3 = stateno = [1000,1250]
trigger3 = movecontact
trigger3 = statetype != A
trigger4 = stateno = 3041 || stateno = 3032 || (stateno = 3030 && hitcount >= 2)
trigger4 = time >= 6
trigger5 = stateno = 1500 || stateno = 1520  || stateno = 1510  || stateno = 1530 || (stateno = 1505 && animelemtime(5)>= 0)
trigger5 = time >= 15

[State -1, Tandem]
type = ChangeState
value = ifelse( var(28) <= 0 , 3100 , 1590) ; 3100
triggerall = (command = "QCF_2k"||command = "DP_2k" && (!var(55) || (p2movetype = H && p2statetype != C && p2statetype != L))) || (var(52) = 1590)
triggerall = power >= 1000
triggerall = !numhelper(3101)
;triggerall = !var(28)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = anim = 233 || anim = 211 || anim = 214 || anim = 218 || anim = 240 || anim = 414 || anim = 444 || anim = 242
trigger2 = movecontact
trigger3 = stateno = [1000,1250]
trigger3 = movecontact
trigger3 = statetype != A
trigger4 = stateno = 3041 || stateno = 3032 || (stateno = 3030 && hitcount >= 2)
trigger4 = time >= 6
trigger5 = stateno = 1500 || stateno = 1520  || stateno = 1510  || stateno = 1530 || (stateno = 1505 && animelemtime(5)>= 0)
trigger5 = time >= 15

[State -1, Himself Mode]
type = ChangeState
value = ifelse(statetype=A,3310,3300)
triggerall = (command = "z") || (var(52) = 3330)
triggerall = !var(55) || (random < ifelse(var(28)=9999,250,800))
triggerall = power >= 1000
triggerall = !numhelper(3101)
triggerall = !numhelper(3200)
triggerall = var(28) = 0 || var(28) = 9999
;triggerall = !var(55)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = anim = 233 || anim = 211 || anim = 214 || anim = 218 || anim = 240 || anim = 414 || anim = 444 || anim = 242
trigger2 = movecontact
trigger3 = stateno = [1000,1250]
trigger3 = movecontact
;trigger3 = statetype != A
trigger4 = stateno = 3041 || stateno = 3032 || (stateno = 3030 && hitcount >= 2)
trigger4 = time >= 6
trigger5 = stateno = 1500 || stateno = 1520  || stateno = 1510  || stateno = 1530 || (stateno = 1505 && animelemtime(5)>= 0)
trigger5 = time >= 15
trigger6 = statetype = A && ctrl
trigger7 = (stateno = [700,740]) && movecontact

[State -1, Portrait]
type = ChangeState
value = ifelse( var(28) <= 0, 3200 , 1690) ; 3200
triggerall = (command = "QCB_2p") || (var(52) = 1690)
triggerall = power >= 1000
triggerall = !numhelper(3101)
triggerall = !numhelper(3200)
triggerall = !var(55) || var(28) <= 0 || p2statetype != A || p2bodydist x <= 40
trigger1 = var(9) ;Use combo condition (above)
trigger2 = anim = 233 || anim = 211 || anim = 214 || anim = 218 || anim = 240 || anim = 414 || anim = 444 || anim = 242
trigger2 = movecontact
trigger3 = stateno = [1000,1250]
trigger3 = movecontact
trigger3 = statetype != A
trigger4 = stateno = 3041 || stateno = 3032 || (stateno = 3030 && hitcount >= 2)
trigger4 = time >= 6
trigger5 = stateno = 1500 || stateno = 1520  || stateno = 1510  || stateno = 1530 || (stateno = 1505 && animelemtime(5)>= 0)
trigger5 = time >= 15

;---------------------------------------------------------------------------
;Stability Stasis Specific
[State -1, Air QCF+AB]
type = ChangeState
value = 1592
triggerall = !numhelper(3101)
triggerall = (command = "QCF_2k") || (var(52) = 1592)
triggerall = var(28) > 0
triggerall = power >= 1000
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,749]) || (stateno = [394,395])
trigger2 = movecontact

[State -1, Air QCB+AB]
type = ChangeState
value = 1740
triggerall = !numhelper(3101)
triggerall = (command = "QCB_2k") || (var(52) = 1740)
triggerall = var(28) > 0
triggerall = power >= 1000
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,749]) || (stateno = [394,395])
trigger2 = movecontact
trigger3 = stateno = 1720
trigger3 = movecontact
trigger4 = stateno = 1550 || stateno = 1570
trigger4 = animelemtime(9) >= 0
trigger4 = (animelemtime(12) < 0) && (movehit)
trigger5 = stateno = 1560 || stateno = 1580
trigger5 = animelemtime(6) >= 0
trigger5 = (animelemtime(9) < 0) && (movehit)
trigger6 = (stateno = 1721) && (time >= 3)

[State -1, Followup]
type = ChangeState
value = 1501
triggerall = !numhelper(3101)
triggerall = (command = "QCF_x") || (var(52) = 1501)
triggerall = stateno = 1500 || stateno = 1520
triggerall = animelemtime(5) >= 0
trigger1 = animelemtime(5) > 3
trigger1 = animelemtime(9) < 0
trigger2 = movecontact

[State -1, Followup]
type = ChangeState
value = 1502
triggerall = !numhelper(3101)
triggerall = (command = "QCF_a" && !var(55)) || (var(52) = 1502)
triggerall = stateno = 1501 || stateno = 1521
trigger1 = animelemtime(3) > 3
trigger1 = animelemtime(6) < 0
trigger2 = movecontact

[State -1, Followup]
type = ChangeState
value = 1521
triggerall = !numhelper(3101)
triggerall = (command = "QCF_y") || (var(52) = 1521)
triggerall = stateno = 1500 || stateno = 1520
triggerall = animelemtime(5) >= 0
trigger1 = animelemtime(5) > 3
trigger1 = animelemtime(9) < 0
trigger2 = movecontact

[State -1, Followup]
type = ChangeState
value = 1522
triggerall = !numhelper(3101)
triggerall = (command = "QCF_b" && !var(55)) || (var(52) = 1522)
triggerall = stateno = 1501 || stateno = 1521
trigger1 = animelemtime(3) > 3
trigger1 = animelemtime(6) < 0
trigger2 = movecontact

[State -1, Followup]
type = ChangeState
value = 1505
triggerall = !numhelper(3101)
triggerall =  (command = "QCF_x"||command = "QCF_y") || (var(52) = 1505)
triggerall = stateno = 1501 || stateno = 1521
trigger1 = animelemtime(3) > 3
trigger1 = animelemtime(6) < 0
trigger2 = movecontact

[State -1, Back Throw]
type = ChangeState
value = 1662
triggerall = (command = "QCF_2p"||command = "DP_2p") || (var(52) = 1662)
triggerall = stateno = 1651
triggerall = power >= 1000
trigger1 = animelemtime(2) >= 0
trigger1 = animelemtime(14) < 0

[State -1, Back Throw]
type = ChangeState
value = 1654
triggerall = (command = "holdback") || (var(52) = 1654)
triggerall = stateno = 1651
trigger1 = animelem = 14

[State -1, Down Throw]
type = ChangeState
value = 1657
triggerall = (command = "holddown") || (var(52) = 1657)
triggerall = stateno = 1651
trigger1 = animelem = 14

[State -1, DP+A DUNK]
type = ChangeState
value = 1551
triggerall = !numhelper(3101)
triggerall = ((command = "QCF_a"||command = "QCF_b") && !var(55)) || (var(52) = 1551)
trigger1 = stateno = 1550 || stateno = 1570
trigger1 = animelemtime(9) >= 0
trigger1 = (animelemtime(12) < 0) || (movecontact)
trigger2 = stateno = 1560 || stateno = 1580
trigger2 = animelemtime(6) >= 0
trigger2 = (animelemtime(9) < 0) || (movecontact)

[State -1, Air QCF+A]
type = ChangeState
value = 1560
triggerall = !numhelper(3101)
triggerall = (command = "QCF_a") || (var(52) = 1560)
triggerall = var(28)>0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,749]) || (stateno = [394,395])
trigger2 = movecontact

[State -1, Air QCF+A]
type = ChangeState
value = 1580
triggerall = !numhelper(3101)
triggerall = (command = "QCF_b") || (var(52) = 1580)
triggerall = var(28)>0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,749]) || (stateno = [394,395])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Specials
[State -1, QCF+X]
type = ChangeState
value = ifelse(var(28)<=0,1100,1500) ; 1100
triggerall = !numhelper(3101)
triggerall = (command = "QCF_x" && (!var(55) || var(28) <= 0 || p2statetype != A)) || (var(52) = 1500)
trigger1 = var(9) ;Use combo condition (above)

[State -1, QCF+Y]
type = ChangeState
value = ifelse(var(28)<=0,1120,1520) ; 1120
triggerall = !numhelper(3101)
triggerall = (command = "QCF_y" && (!var(55) || var(28) <= 0 || p2statetype != A)) || (var(52) = 1520)
trigger1 = var(9) ;Use combo condition (above)

[State -1, QCB+X]
type = ChangeState
value = ifelse(var(28)<=0,1200,1650) ; 1200
triggerall = !numhelper(3101)
triggerall = (command = "QCB_x" && (!var(55) || var(28) <= 0 || p2statetype != A)) || (var(52) = 1650)
trigger1 = var(9) ;Use combo condition (above)

[State -1, QCB+Y]
type = ChangeState
value = ifelse(var(28)<=0,1220,1670) ; 1220
triggerall = !numhelper(3101)
triggerall = (command = "QCB_y" && (!var(55) || var(28) <= 0 || p2statetype != A)) || (var(52) = 1670)
trigger1 = var(9) ;Use combo condition (above)

[State -1, DP+A]
type = ChangeState
value = ifelse(var(28)<=0,1050,1550) ; 1050
triggerall = !numhelper(3101)
triggerall = (command = "DP_a" && (!var(55) || var(28) <= 0)) || (var(52) = 1550)
trigger1 = var(9) ;Use combo condition (above)
trigger1 = (stateno != 52) || (prevstateno != [1050,1070])

[State -1, DP+B]
type = ChangeState
value = ifelse(var(28)<=0,1070,1570) ; 1070
triggerall = !numhelper(3101)
triggerall = (command = "DP_b" && (!var(55) || var(28) <= 0)) || (var(52) = 1570)
trigger1 = var(9) ;Use combo condition (above)
trigger1 = (stateno != 52) || (prevstateno != [1050,1070])

[State -1, HCB+A]
type = ChangeState
value = ifelse(var(28)<=0,1250,1750) ;1250
triggerall = !numhelper(3101)
triggerall = (command = "HCB_a") || (var(52) = 1750)
;triggerall = var(28) <= 0
trigger1 = var(9) ;Use combo condition (above)
trigger2 = stateno = 1510 || stateno = 1530
trigger2 = movecontact && animelemtime(5) > 0

[State -1, HCB+B]
type = ChangeState
value = ifelse(var(28)<=0,1270,1770)
triggerall = !numhelper(3101)
triggerall = (command = "HCB_b") || (var(52) = 1770)
;triggerall = var(28) <= 0
trigger1 = var(9) ;Use combo condition (above)
trigger2 = stateno = 1510 || stateno = 1530
trigger2 = movecontact && animelemtime(5) > 0

[State -1, QCB+B]
type = ChangeState
value = 1642
triggerall = !numhelper(3101)
triggerall = (command = "QCB_2k" && (!var(55) || var(28) <= 0)) || (var(52) = 1642)
triggerall = var(28) > 0
trigger1 = var(9) ;Use combo condition (above)

[State -1, QCB+A]
type = ChangeState
value = ifelse(var(28)<=0,1000,1610)
triggerall = !numhelper(3101)
triggerall = (command = "QCB_a" && (!var(55) || var(28) <= 0)) || (var(52) = 1610)
trigger1 = var(9) ;Use combo condition (above)

[State -1, QCB+B]
type = ChangeState
value = ifelse(var(28)<=0,1020,1630)
triggerall = !numhelper(3101)
triggerall = (command = "QCB_b" && (!var(55) || var(28) <= 0)) || (var(52) = 1630)
trigger1 = var(9) ;Use combo condition (above)

[State -1, QCF+A]
type = ChangeState
value = ifelse(var(28)<=0,1150,1510)
triggerall = !numhelper(3101)
triggerall = (command = "QCF_a") || (var(52) = 1510)
trigger1 = var(9) ;Use combo condition (above)

[State -1, QCF+B]
type = ChangeState
value = ifelse(var(28)<=0,1170,1530)
triggerall = !numhelper(3101)
triggerall = (command = "QCF_b") || (var(52) = 1530)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = stateno = 1510
trigger2 = movecontact && animelemtime(5) > 0

[State -1, DD+2K]
type = ChangeState
value = 1640
triggerall = !numhelper(3101)
;triggerall = !numhelper(1645)
triggerall = (command = "DD_2k") || (var(52) = 1640)
triggerall = var(28) > 0
triggerall = power >= 1000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = anim = 233 || anim = 211 || anim = 214 || anim = 218 || anim = 240 || anim = 414 || anim = 444 || anim = 242
trigger2 = movecontact
trigger3 = stateno = [1000,1250]
trigger3 = movecontact
trigger3 = statetype != A
trigger4 = stateno = 3041 || stateno = 3032 || (stateno = 3030 && hitcount >= 2)
trigger4 = time >= 6
trigger5 = stateno = 1500 || stateno = 1520  || stateno = 1510  || stateno = 1530 || (stateno = 1505 && animelemtime(5)>= 0)
trigger5 = time >= 12

[State -1, DD+A]
type = ChangeState
value = 1600
triggerall = !numhelper(3101)
triggerall = !numprojid(1600)
triggerall = (command = "DD_a" && (!var(55) || var(28) <= 0)) || (var(52) = 1600)
triggerall = var(28) > 0
trigger1 = var(9) ;Use combo condition (above)

[State -1, DD+B]
type = ChangeState
value = 1620
triggerall = !numhelper(3101)
triggerall = !numprojid(1600)
triggerall = (command = "DD_b" && (!var(55) || var(28) <= 0)) || (var(52) = 1620)
triggerall = var(28) > 0
trigger1 = var(9) ;Use combo condition (above)

[State -1, Air QCB+A]
type = ChangeState
value = ifelse(var(28)<=0,1300,1700)
triggerall = !numhelper(3101)
triggerall = (command = "QCB_a" && (!var(55) || var(28) <= 0 || p2statetype != A)) || (var(52) = 1700)
triggerall = stateno != 1721
;triggerall = var(28) <= 0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,749]) || (stateno = [394,395])
trigger2 = movecontact

[State -1, Air QCB+B]
type = ChangeState
value = ifelse(var(28)<=0,1320,1720)
triggerall = !numhelper(3101)
triggerall = (command = "QCB_b" && (!var(55) || var(28) <= 0 || p2statetype != A)) || (var(52) = 1720)
triggerall = stateno != 1721
;triggerall = var(28) <= 0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,749]) || (stateno = [394,395])
trigger2 = movecontact

[State -1, Shield Bunker]
type = ChangeState
value = 396
;triggerall = !numhelper(3101)
triggerall = (command = "QCB_pari") || var(52) = 396
triggerall = statetype != A
trigger1 = var(9)
trigger1 = stateno != 391
trigger2 = stateno = 390 || stateno = 392
trigger2 = movecontact >= 2
trigger3 = stateno = [130,153]
trigger3 = power >= 500
;trigger2 = ((stateno = 400) && (anim != 402)) || ((stateno = 430) && (anim = 434))
;trigger2 = (time > 9) || (movecontact && (time >= 6 || anim != 401) )

[State -1, Shield Followup]
type = ChangeState
value = 391
;triggerall = !numhelper(3101)
triggerall = (command = "QCF_pari") || var(52) = 391
triggerall = statetype != A
trigger1 = stateno = 390 || stateno = 392
trigger1 = movecontact
;trigger2 = ((stateno = 400) && (anim != 402)) || ((stateno = 430) && (anim = 434))
;trigger2 = (time > 9) || (movecontact && (time >= 6 || anim != 401) )

[State -1, Shield Followup]
type = ChangeState
value = 395
;triggerall = !numhelper(3101)
triggerall = (command = "QCF_pari") || var(52) = 395
trigger1 = stateno = 394
trigger1 = movecontact
;trigger2 = ((stateno = 400) && (anim != 402)) || ((stateno = 430) && (anim = 434))
;trigger2 = (time > 9) || (movecontact && (time >= 6 || anim != 401) )


;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = !numhelper(3101)
triggerall = stateno != 100
triggerall = stateno != 1610
triggerall = stateno != 1630
triggerall = (command = "FF") || (var(52) = 100)
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = !numhelper(3101)
triggerall = stateno != 1610
triggerall = stateno != 1630
triggerall = (command = "BB") || (var(52) = 105)
trigger1 = statetype = S
trigger1 = ctrl

[State -1, Run Fwd]
type = ChangeState
value = 110
triggerall = !numhelper(3101)
triggerall = stateno != 100 || stateno != 105 || stateno != 106
triggerall = stateno != [110,115]
triggerall = (command = "AFF") || (var(52) = 100)
trigger1 = statetype = A
trigger1 = pos y <= -15
trigger1 = ctrl
trigger1 = stateno != [110,115]
trigger2 = stateno = 700 || stateno = 730
trigger2 = movecontact || animelemtime(4) >= 0

[State -1, Run Fwd]
type = ChangeState
value = 115
triggerall = !numhelper(3101)
triggerall = stateno != 100 || stateno != 105 || stateno != 106
triggerall = stateno != [110,115]
triggerall = (command = "ABB") || (var(52) = 105)
trigger1 = statetype = A
trigger1 = pos y <= -15
trigger1 = ctrl
trigger1 = stateno != [110,115]
trigger2 = stateno = 700 || stateno = 730
trigger2 = movecontact || animelemtime(4) >= 0

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = var(8) <= 0
triggerall = !numhelper(3101)
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd" || command = "holdback"
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

[State -1, Kung Fu Throw]
type = ChangeState
value = 830
triggerall = var(8) <= 0
triggerall = !numhelper(3101)
triggerall = command = "b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd" || command = "holdback"
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

[State -1, Air Throw]
type = ChangeState
value = 870
triggerall = command = "y" || command = "b"
triggerall = statetype = A
triggerall = ctrl
triggerall = !numhelper(3101)
trigger1 = command = "holdfwd" || command = "holdback"
trigger1 = p2bodydist X < 25
trigger1 = abs(p2bodydist y) < 75
trigger1 = (p2statetype = A)
;trigger1 = p2movetype != H


;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Forward Punch Attack]
type = ChangeState
value = 220 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "x") && (command != "holddown") && (command = "holdfwd")) || var(52) = 220
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,249]) || (stateno = [400,440])
trigger2 = stateno != 220
trigger2 = stateno != 250
trigger2 = anim != 233 && anim != 211 && anim != 214 && anim != 218 && anim != 240 && anim != 414 && anim != 444 && anim != 242
trigger2 = (time > 12) || movecontact
trigger3 = (stateno = 1120 && anim = 1121)
trigger3 = (time > 9) || movehit
trigger4 = (stateno = 300) || (stateno = 330) || (stateno = 310) || (stateno = 500) || (stateno = 530) || (stateno = 510) || (stateno = 340) || (stateno = 540)
trigger4 = movecontact
trigger4 = prevstateno != 350
trigger4 = movecontact

[State -1, Forward Kick Attack]
type = ChangeState
value = 250 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "a") && (command != "holddown") && (command = "holdfwd")) || var(52) = 250
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,249]) || (stateno = [400,440])
trigger2 = stateno != 220
trigger2 = stateno != 250
trigger2 = anim != 233 && anim != 211 && anim != 214 && anim != 218 && anim != 240 && anim != 414 && anim != 444 && anim != 242 && anim != 243
trigger2 = (time > 12) || movecontact
trigger3 = (stateno = 1120 && anim = 1121)
trigger3 = (time > 9) || movehit
trigger4 = (stateno = 300) || (stateno = 330) || (stateno = 310) || (stateno = 500) || (stateno = 530) || (stateno = 510) || (stateno = 340) || (stateno = 540)
trigger4 = prevstateno != 350
trigger4 = movecontact


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "x") && (command != "holddown") || anim = 403 || anim = 432) || var(52) = 200
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && (anim != 201 && anim != 202)
trigger2 = (time > 6) || movecontact
trigger3 = ((stateno = 430) && (anim = 432)) || ((stateno = 230) && (anim = 233)) || ((stateno = 240) && (anim = 246) && movecontact) || ((stateno = 400) && (anim = 403)) || ((stateno = 430) && (anim = 432))
trigger3 = (time > 9) || movecontact
trigger4 = (stateno = 1120 && anim = 1121) || (stateno = 1150 && anim = 1157)
trigger4 = ((time > 9) || movehit) && (p2statetype != A)
trigger5 = (stateno = 300) || (stateno = 330)
trigger5 = (time > 9) || movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "y") && (command != "holddown")) || var(52) = 210
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 230 && anim != 232)
trigger2 = (time > 6) || movecontact
trigger3 = (stateno = 210 && anim = 216) || ((stateno = 430) && (anim = 432))
trigger3 = (time > 6) || movecontact
trigger4 = (stateno = 1100 && anim = 1101 && animelemtime(12) >= 0)
trigger4 = ((time > 9) || movehit) && (p2statetype != A)
trigger5 = (stateno = 300) || (stateno = 330) || (stateno = 500) || (stateno = 530)
trigger5 = (time > 9) || movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "a") && (command != "holddown")) || var(52) = 230
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 230 && anim != 232)
trigger2 = (time > 6) || movecontact
trigger2 = anim != [231,239]
trigger3 = (stateno = 210 && anim = 216) || ((stateno = 240) && (anim = 246) && movecontact)
trigger3 = (time > 6) || movecontact
trigger4 = (stateno = 1120 && anim = 1121) || (stateno = 1150 && anim = 1157)
trigger4 = ((time > 9) || movehit) && (p2statetype != A)
trigger5 = (stateno = 300) || (stateno = 330)
trigger5 = (time > 9) || movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "b") && (command != "holddown")) || var(52) = 240
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 230 && anim != 232)
trigger2 = (time > 6) || movecontact
trigger3 = (stateno = 210 && anim = 216) || (stateno = 250 && anim = 250) || (stateno = 210 && anim = 213)
trigger3 = (time > 9) || movecontact
trigger4 = (stateno = 1100 && anim = 1101 && animelemtime(12) >= 0)
trigger4 = ((time > 9) || movehit) && (p2statetype != A)
trigger5 = (stateno = 300) || (stateno = 330) || (stateno = 310) || (stateno = 500) || (stateno = 530) || (stateno = 510) || (stateno = 350)
trigger5 = prevstateno != 340
trigger5 = (time > 13) || movecontact


;---------------------------------------------------------------------------
;Taunt
;
[State -1, Dodge]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = var(28) > 0
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Taunt]
type = Helper
triggerall = command = "start"
triggerall = !numhelper(195)
triggerall = var(28) <= 0
trigger1 = statetype != A
trigger1 = ctrl
helpertype = normal ;player
name = "CARL WINSLOW"
ID = 195
stateno = 195
pos = 0,0
postype = p1
facing = 1
ownpal = 1
supermovetime = 65535
pausemovetime = 65535
ignorehitpause = 1

[State -1, Standing Parry]
type = ChangeState
value = 390
;triggerall = !numhelper(3101)
triggerall = ((command = "c") && (command != "holddown")) || var(52) = 390
triggerall = !var(55) || (p2movetype != H && random < 100)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 390 || stateno = 392
trigger2 = movecontact >= 2
;trigger2 = ((stateno = 400) && (anim != 402)) || ((stateno = 430) && (anim = 434))
;trigger2 = (time > 9) || (movecontact && (time >= 6 || anim != 401) )

[State -1, Crouching Parry]
type = ChangeState
value = 392
;triggerall = !numhelper(3101)
triggerall = ((command = "c") && (command = "holddown")) || var(52) = 392
triggerall = !var(55) || (p2movetype != H && random < 100)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 390 || stateno = 392
trigger2 = movecontact >= 2
;trigger2 = ((stateno = 400) && (anim != 402)) || ((stateno = 430) && (anim = 434))
;trigger2 = (time > 9) || (movecontact && (time >= 6 || anim != 401) )

[State -1, Aerial Parry]
type = ChangeState
value = 394
;triggerall = !numhelper(3101)
triggerall = (command = "c") || var(52) = 394
triggerall = !var(55) || (p2movetype != H && random < 100)
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 394
trigger2 = movecontact >= 2
;trigger2 = ((stateno = 400) && (anim != 402)) || ((stateno = 430) && (anim = 434))
;trigger2 = (time > 9) || (movecontact && (time >= 6 || anim != 401) )

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "x") && (command = "holddown")) || var(52) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = ((stateno = 400) && (anim != 402)) || ((stateno = 430) && (anim = 434))
trigger2 = (time > 9) || (movecontact && (time >= 6 || anim != 401) )
trigger3 = (stateno = 500) || (stateno = 530)
trigger3 = (time > 9) || movecontact

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "y") && (command = "holddown")) || var(52) = 410
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430 && anim != 433)
trigger2 = (time > 9) || (movecontact)
trigger3 = (stateno = 440 && anim = 442)
trigger3 = (time > 6) || movecontact
trigger4 = (stateno = 500) || (stateno = 530) || (stateno = 300) || (stateno = 330) || (stateno = 310)
trigger4 = (time > 13) || movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "a") && (command = "holddown")) || var(52) = 430
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430 && anim != 431 && anim != 433 && anim != 434)
trigger2 = (time > 9) || (movecontact && time > 5)
trigger3 = (stateno = 500) || (stateno = 530)
trigger3 = (time > 9) || movecontact

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = ((command = "b") && (command = "holddown")) || var(52) = 440
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430 && anim != 433)
trigger2 = (time > 9) || (movecontact)
trigger3 = (stateno = 500) || (stateno = 530) || (stateno = 510) || (stateno = 300) || (stateno = 330) || (stateno = 310)
trigger3 = (time > 13) || movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = (command = "x") || var(52) = 600
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 && anim = 600) || stateno = 630
trigger2 = statetime >= 12 || movecontact
trigger3 = (stateno = 1020 && anim = 1022)
trigger3 = movecontact
;trigger4 = (stateno = 700) || (stateno = 730)
;trigger4 = (time > 13) || movecontact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = (command = "y") || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || (stateno = 640 && anim != 640 && anim != 644 && anim != 643)
trigger2 = movecontact
trigger3 = (stateno = 1020 && anim = 1022)
trigger3 = movecontact
trigger4 = (stateno = 700) || (stateno = 730)
trigger4 = (time > 13) || movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = (command = "a") || var(52) = 630
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 1020 && anim = 1022)
trigger2 = movecontact
;trigger3 = (stateno = 700) || (stateno = 730)
;trigger3 = (time > 13) || movecontact


;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640 + ifelse(var(28)>0,100,0)
triggerall = !numhelper(3101)
triggerall = (command = "b") || var(52) = 640
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = (stateno = 1020 && anim = 1022)
trigger3 = movecontact
trigger4 = (stateno = 700) || (stateno = 730); || (stateno = 710)
trigger4 = (time > 13) || movecontact

; MVC
[State -1, Jump-In]
type = ChangeState
value = 40
triggerall = !numhelper(3101)
triggerall = (command = "holdup") || var(52) = 40
trigger1 = (stateno = 410 && anim = 412)
trigger1 = time > 12 || movecontact
trigger2 = (stateno = 320) || (stateno = 510) || (stateno = 391)
trigger2 = time > 17 || movecontact
trigger3 = (stateno = 1750) || (stateno = 1770) || (stateno = 1790)
trigger3 = (animelemtime(8) >= 0) && (movecontact)
;trigger2 = (stateno = 1156)
;trigger2 = animelemtime(9) >= 0

[State -1, LOL GG]
type = ChangeState
value = 45
triggerall = !numhelper(3101)
triggerall = (command = "holdup") || var(52) = 45
triggerall = var(27) = 0
trigger1 = (stateno = 740 && anim = 741)
trigger1 = movecontact

; AI GUARDING

[State AI, Guard S]
type = ChangeState
triggerall = stateno != 40
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = stateno != 390
triggerall = var(54) != 2
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<64&&(stateno!=[120,169])&&p2bodydist x<=80,ifelse(random<150,ifelse(random<150&&var(28)>0&&p2statetype!=A,1600,396),390),130)

[State AI, Guard L]
type = ChangeState
triggerall = stateno != 40
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = stateno != 392
triggerall = var(54) != 2
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<50&&(stateno!=[120,169])&&p2bodydist x<=80,ifelse(random<150&&power>=1000&&var(28)>0,1640,ifelse(random<100,40,392)),131)

[State AI, Parry A]
type = ChangeState
triggerall = !numhelper(3101)
;triggerall = power
;triggerall = var(54) != 1
triggerall = random < 100
triggerall = stateno != [120,169]
triggerall = prevstateno != [120,169]
triggerall = stateno != 394
triggerall = var(54) != 2
triggerall = (var(55)) && (StateType = A) && (Ctrl) && (EnemyNear, Facing != Facing)
trigger1 = (var(54)!=2) && (P2MoveType = A) && ((inguarddist) || (EnemyNear, NumProj > 0)) && (enemynear,moveguarded < 12) && (!var(51))
trigger2 = (var(54)=2) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = 394



